@@ -9,6 +9,7 @@ import os
 import re
 
 from spython.logger import bot
+
 from .base import ParserBase
 
 
@@ -425,6 +426,8 @@ class DockerParser(ParserBase):
         """
         # Save the last working directory to add to the runscript
         workdir = self._setup("WORKDIR", line)
+        workdir_mkdir = "mkdir -p %s" % ("".join(workdir))
+        self.recipe[self.active_layer].install.append(workdir_mkdir)
         workdir_cd = "cd %s" % ("".join(workdir))
         self.recipe[self.active_layer].install.append(workdir_cd)
         self.recipe[self.active_layer].workdir = workdir[0]
