@@ -5,11 +5,12 @@
 # with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 
-from spython.logger import bot
-from spython.utils import stream_command, ScopedEnvVar
 import os
 import re
 
+from spython.logger import bot
+from spython.utils import ScopedEnvVar, stream_command
+
 
 def pull(
     self,
